==> haskell-configfile-1.1.4-58-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ConfigFile
version: 1.1.4
id: ConfigFile-1.1.4-DnXxhWLQL4jBFVyu6Xp3eo
key: ConfigFile-1.1.4-DnXxhWLQL4jBFVyu6Xp3eo
license: BSD-3-Clause
copyright: Copyright (c) 2004-2014 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Stable
homepage: http://software.complete.org/configfile
synopsis: Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.
    .
    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.
    .
    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.
category: Parsing
abi: 188d6d6135bc158cf870e87ae265e4e3
exposed: True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types
hidden-modules: Data.ConfigFile.Lexer
import-dirs: /usr/lib/ghc-8.6.5/site-local/ConfigFile-1.1.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ConfigFile-1.1.4
hs-libraries: HSConfigFile-1.1.4-DnXxhWLQL4jBFVyu6Xp3eo
depends:
    MissingH-1.4.1.0-1U6Bi93w0keAfxYYYFGQLZ base-4.12.0.0
    containers-0.6.0.1 mtl-2.2.2 parsec-3.1.13.0
haddock-interfaces: /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html: /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configfile-1.1.4-59-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ConfigFile
version: 1.1.4
id: ConfigFile-1.1.4-J8WJr9HNtZs81D4gRdEohJ
key: ConfigFile-1.1.4-J8WJr9HNtZs81D4gRdEohJ
license: BSD-3-Clause
copyright: Copyright (c) 2004-2014 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Stable
homepage: http://software.complete.org/configfile
synopsis: Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.
    .
    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.
    .
    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.
category: Parsing
abi: dd4ecff796f094e9c48d5be4b91aeccf
exposed: True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types
hidden-modules: Data.ConfigFile.Lexer
import-dirs: /usr/lib/ghc-8.6.5/site-local/ConfigFile-1.1.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ConfigFile-1.1.4
hs-libraries: HSConfigFile-1.1.4-J8WJr9HNtZs81D4gRdEohJ
depends:
    MissingH-1.4.2.0-168dh7um0zAEtmrOAswoIx base-4.12.0.0
    containers-0.6.0.1 mtl-2.2.2 parsec-3.1.13.0
haddock-interfaces: /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html: /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
